@@ -5,6 +5,8 @@ import ctypes
 import threading
 import time
 import warnings
+import platform
+import signal
 
 def shut_up(*args, **kwargs):
     return
@@ -78,8 +80,24 @@ def set_windows_event_loop_policy():
         asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
 
 
+def macos_bigsur_wants_layer():
+    # workaround for https://bugreports.qt.io/browse/QTBUG-87014
+    # this is because the latest PySide2 (5.15.2) does not include this fix
+    v, _, _ = platform.mac_ver()
+    vs = v.split(".")
+    if len(vs) >= 2:
+        major, minor = list(map(int, vs[:2]))
+    else:
+        return
+    if major >= 11 or major == 10 and minor == 16:
+        os.environ['QT_MAC_WANTS_LAYER'] = '1'
+
+
 def start_management(filepath=None, use_daemon=False):
 
+    if sys.platform == "darwin":
+        macos_bigsur_wants_layer()
+
     if not check_dependencies():
         sys.exit(1)
 
@@ -91,10 +109,18 @@ def start_management(filepath=None, use_daemon=False):
     from PySide2.QtCore import Qt
 
     from .config import FONT_LOCATION, IMG_LOCATION, Conf
+    from .ui.css import refresh_theme
 
     app = QApplication(sys.argv)
     app.setApplicationDisplayName("angr management")
     app.setApplicationName("angr management")
+    icon_location = os.path.join(IMG_LOCATION, 'angr.png')
+    QApplication.setWindowIcon(QIcon(icon_location))
+
+    # try to import the initial configuration for the install
+    Conf.attempt_importing_initial_config()
+
+    refresh_theme()
 
     # URL scheme
     from .logic.url_scheme import AngrUrlScheme
@@ -130,7 +156,6 @@ def start_management(filepath=None, use_daemon=False):
         app.processEvents()
 
     from .logic import GlobalInfo
-    from .ui.css import CSS
     from .ui.main_window import MainWindow
     from .daemon import daemon_exists, run_daemon_process, daemon_conn
     from .daemon.client import ClientService
@@ -146,9 +171,6 @@ def start_management(filepath=None, use_daemon=False):
 
     GlobalInfo.gui_thread = threading.get_ident()
 
-    # apply the CSS
-    app.setStyleSheet(CSS.global_css())
-
     if use_daemon:
         # connect to daemon (if there is one)
         if not daemon_exists():
@@ -183,6 +205,7 @@ def start_management(filepath=None, use_daemon=False):
 
 def main():
     import argparse
+    signal.signal(signal.SIGINT, signal.SIG_DFL)
 
     parser = argparse.ArgumentParser(description="angr management")
     parser.add_argument("-s", "--script", type=str, help="run a python script in the (commandline) angr environment")
