@@ -3,7 +3,7 @@
 class JumpHistory(object):
     def __init__(self):
         self._history = [ ]
-        self._pos = 0
+        self._pos = -1
 
     def __len__(self):
         return len(self._history)
@@ -17,6 +17,7 @@ class JumpHistory(object):
             self._history.append(addr)
             self._pos = len(self._history) - 1
 
+    # TODO this should maybe not adjust pos and just update the most recent entry
     def record_address(self, addr):
 
         if self._pos != len(self._history) - 1:
@@ -30,10 +31,10 @@ class JumpHistory(object):
         self._history = self._history[ : self._pos + 1]
 
     def backtrack(self):
-        if self._pos > 0:
+        if self._pos > -1:
             self._pos -= 1
 
-        if self._pos >= len(self._history):
+        if not (0 <= self._pos < len(self._history)):
             return None
         else:
             return self._history[self._pos]
