@@ -1,6 +1,6 @@
 import logging
 
-from PySide2.QtGui import QColor, QPen, QPainterPath
+from PySide2.QtGui import QPen, QPainterPath
 from PySide2.QtCore import QRectF, QMarginsF
 
 from angr.analyses.disassembly import Instruction
@@ -120,7 +120,9 @@ class QBlock(QCachedGraphicsItem):
             self._block_item_obj = None
 
         self._block_item = QPainterPath()
-        self._block_item.addRect(0, 0, self.width, self.height)
+        self._block_item.addRoundedRect(0, 0, self.width, self.height,
+            self._config.disasm_view_node_rounding,
+            self._config.disasm_view_node_rounding)
 
     def _init_widgets(self):
 
@@ -203,7 +205,7 @@ class QGraphBlock(QBlock):
             return color
 
         if should_omit_text:
-            return QColor(0xda, 0xda, 0xda)
+            return self._config.disasm_view_node_zoomed_out_background_color
 
         return self._config.disasm_view_node_background_color
 
@@ -211,12 +213,19 @@ class QGraphBlock(QBlock):
         lod = option.levelOfDetailFromTransform(painter.worldTransform())
         should_omit_text = lod < QGraphBlock.MINIMUM_DETAIL_LEVEL
 
+        painter.setBrush(self._config.disasm_view_node_shadow_color)
+        painter.setPen(self._config.disasm_view_node_shadow_color)
+        shadow_path = QPainterPath(self._block_item)
+        shadow_path.translate(5,5)
+        painter.drawPath(shadow_path)
+
         # background of the node
         painter.setBrush(self._calc_backcolor(should_omit_text))
         if self.infodock.is_block_selected(self.addr):
             painter.setPen(QPen(self._config.disasm_view_selected_node_border_color, 2.5))
         else:
             painter.setPen(QPen(self._config.disasm_view_node_border_color, 1.5))
+
         self._block_item_obj = painter.drawPath(self._block_item)
 
         # content drawing is handled by qt since children are actual child widgets
@@ -243,11 +252,17 @@ class QGraphBlock(QBlock):
 class QLinearBlock(QBlock):
     ADDRESS_PADDING = 10
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self._height = 0
+        self._width = 0
+
     @property
     def mode(self):
         return 'linear'
 
-    def format_address(self, addr):
+    @staticmethod
+    def format_address(addr):
         return '{:08x}'.format(addr)
 
     def layout_widgets(self):
