@@ -2,13 +2,14 @@ from typing import TYPE_CHECKING
 
 from PySide2.QtCore import Qt, QEvent
 from PySide2.QtGui import QTextCharFormat
-from PySide2.QtWidgets import QMenu, QAction
+from PySide2.QtWidgets import QMenu, QAction, QInputDialog, QLineEdit
 
 from pyqodeng.core import api
 from pyqodeng.core import modes
 from pyqodeng.core import panels
 
-from angr.analyses.decompiler.structured_codegen import CBinaryOp, CVariable, CFunctionCall, CFunction
+from angr.sim_variable import SimVariable, SimTemporaryVariable
+from angr.analyses.decompiler.structured_codegen.c import CBinaryOp, CVariable, CFunctionCall, CFunction
 
 from ..dialogs.rename_node import RenameNode
 from ..widgets.qccode_highlighter import QCCodeHighlighter
@@ -53,11 +54,10 @@ class QCCodeEdit(api.CodeEdit):
         self.call_actions = [ ]
         self.default_actions = [ ]
         self.function_name_actions = []
-        self._initialize_context_menus()
-
+        self.action_rename_node = None
         self._selected_node = None
 
-        self.action_rename_node = None
+        self._initialize_context_menus()
 
         # but we don't need some of the actions
         self.remove_action(self.action_undo)
@@ -127,15 +127,17 @@ class QCCodeEdit(api.CodeEdit):
 
     def event(self, event):
         """
-        Reimplemented to capture the Tab key pressed event.
+        Reimplemented to capture the Tab key pressed/released event.
 
         :param event:
         :return:
         """
 
-        if event.type() == QEvent.KeyRelease and event.key() == Qt.Key_Tab:
-            self.keyReleaseEvent(event)
+        if event.type() == QEvent.ShortcutOverride and event.key() == Qt.Key_Tab:
+            event.accept()
             return True
+        if event.type() == QEvent.KeyPress and event.key() == Qt.Key_Tab:
+            return self.keyPressEvent(event)
 
         return super().event(event)
 
@@ -168,21 +170,20 @@ class QCCodeEdit(api.CodeEdit):
 
         return asm_ins_addr
 
-    def keyReleaseEvent(self, event):
+    def keyPressEvent(self, event):
         key = event.key()
-        if key == Qt.Key_Tab:
-            # Compute the location to switch back to
-            asm_inst_addr = self.get_src_to_inst()
+        node = self.node_under_cursor()
 
-            # Switch back to disassembly view
-            self.workspace.jump_to(asm_inst_addr)
+        if key == Qt.Key_N:
+            if isinstance(node, (CVariable, CFunction, CFunctionCall)):
+                self.rename_node(node=node)
             return True
-        elif key == Qt.Key_N:
-            node = self.node_under_cursor()
-            if isinstance(node, (CVariable, CFunction)):
-                self.rename_node(node)
+        if key in (Qt.Key_Slash, Qt.Key_Question):
+            self.comment(expr=event.modifiers() & Qt.ShiftModifier == Qt.ShiftModifier)
             return True
 
+        if self._code_view.keyPressEvent(event):
+            return True
         return super().keyPressEvent(event)
 
     def setDocument(self, document):
@@ -195,13 +196,68 @@ class QCCodeEdit(api.CodeEdit):
     # Actions
     #
 
-    def rename_node(self, node=None):
+    def rename_node(self, *args, node=None):  # pylint: disable=unused-argument
         n = node if node is not None else self._selected_node
-        if not isinstance(n, (CVariable, CFunction)):
+        if not isinstance(n, (CVariable, CFunction, CFunctionCall)):
+            return
+        if isinstance(n, CVariable) and isinstance(n.variable, SimTemporaryVariable):
+            # unsupported right now..
             return
         dialog = RenameNode(code_view=self._code_view, node=n)
         dialog.exec_()
 
+    def comment(self, expr=False, node=None):
+        addr = (getattr(node, 'tags', None) or {}).get('ins_addr', None)
+        if addr is None:
+            if expr:
+                addr = self.get_src_to_inst()
+            else:
+                pos = self.textCursor().position()
+                while self.document().characterAt(pos) not in ('\n', '\u2029') and pos < self.document().characterCount():  # qt WHAT are you doing
+                    pos += 1
+                node = self.document().get_stmt_node_at_position(pos)
+                addr = (getattr(node, 'tags', None) or {}).get('ins_addr', None)
+
+        if addr is None:
+            return
+
+        try:
+            cdict = self._code_view.codegen.expr_comments if expr else self._code_view.codegen.stmt_comments
+        except AttributeError:
+            return
+        text = cdict.get(addr, "")
+
+        text, ok = QInputDialog.getText(
+            self._code_view,
+            "Expression Comment" if expr else "Statement Comment",
+            "",
+            QLineEdit.Normal,
+            text)
+
+        if ok:
+            if text:
+                cdict[addr] = text
+            else:
+                try:
+                    del cdict[addr]
+                except KeyError:
+                    pass
+
+            self._code_view.codegen.am_event()
+
+    def toggle_struct(self):
+        node = self._selected_node
+        if not isinstance(node, CVariable):
+            return
+        if isinstance(node.variable, SimVariable):
+            ident = node.variable.ident
+            if ident in self._code_view.vars_must_struct:
+                self._code_view.vars_must_struct.remove(ident)
+            else:
+                self._code_view.vars_must_struct.add(ident)
+            # decompile again
+            self._code_view.decompile()
+
     @staticmethod
     def _separator():
         sep = QAction()
@@ -218,9 +274,12 @@ class QCCodeEdit(api.CodeEdit):
 
         self.action_rename_node = QAction('Re&name variable', self)
         self.action_rename_node.triggered.connect(self.rename_node)
+        self.action_toggle_struct = QAction('Toggle &struct/array')
+        self.action_toggle_struct.triggered.connect(self.toggle_struct)
 
         self.variable_actions = [
             self.action_rename_node,
+            self.action_toggle_struct,
         ]
 
         self.function_name_actions = [
