@@ -1,7 +1,7 @@
 from typing import List
 import logging
 
-from PySide2.QtGui import QPainter, QColor, QCursor
+from PySide2.QtGui import QPainter, QCursor
 from PySide2.QtCore import Qt, QRectF
 from PySide2.QtWidgets import QApplication, QGraphicsSceneMouseEvent
 
@@ -51,6 +51,8 @@ class QInstruction(QCachedGraphicsItem):
         self._comment = None
         self._comment_width = None
         self._legend = None
+        self._width = 0
+        self._height = 0
 
         self._init_widgets()
 
@@ -83,7 +85,7 @@ class QInstruction(QCachedGraphicsItem):
             return color
 
         if self.selected:
-            return QColor(0xb8, 0xc3, 0xd6)
+            return self._config.disasm_view_node_instruction_selected_background_color
 
         return None  # None here means transparent, reusing the block color
 
@@ -138,12 +140,12 @@ class QInstruction(QCachedGraphicsItem):
 
         # address
         if self.disasm_view.show_address:
-            painter.setPen(Qt.black)
+            painter.setPen(self._config.disasm_view_node_address_color)
             painter.drawText(x, y, self._addr)
             x += self._addr_width + self.GRAPH_ADDR_SPACING * self.currentDevicePixelRatioF()
 
         # mnemonic
-        painter.setPen(QColor(0, 0, 0x80))
+        painter.setPen(self._config.disasm_view_node_mnemonic_color)
         painter.drawText(x, y, self._mnemonic)
         x += self._mnemonic_width
 
