@@ -1,7 +1,7 @@
 import logging
 
 from PySide2.QtWidgets import QApplication
-from PySide2.QtGui import QPainter, QColor
+from PySide2.QtGui import QPainter
 from PySide2.QtCore import Qt, QRectF, QPointF
 
 from angr.analyses.disassembly import ConstantOperand, RegisterOperand, MemoryOperand, Value
@@ -125,13 +125,13 @@ class QOperand(QCachedGraphicsItem):
         button = event.button()
         if button == Qt.LeftButton:
             if self._branch_target is not None:
-                self.disasm_view.jump_to(self._branch_target, src_ins_addr=self.insn.addr)
+                self.disasm_view.jump_to(self._branch_target, src_ins_addr=self.insn.addr, use_animation=True)
                 return
             if self.is_constant:
-                self.disasm_view.jump_to(self.constant_value, src_ins_addr=self.insn.addr)
+                self.disasm_view.jump_to(self.constant_value, src_ins_addr=self.insn.addr, use_animation=True)
                 return
             if self.is_constant_memory:
-                self.disasm_view.jump_to(self.constant_memory_value, src_ins_addr=self.insn.addr)
+                self.disasm_view.jump_to(self.constant_memory_value, src_ins_addr=self.insn.addr, use_animation=True)
         else:
             super().mouseDoubleClickEvent(event)
 
@@ -172,7 +172,10 @@ class QOperand(QCachedGraphicsItem):
                 #        fallback = False
                 pass
 
-            painter.setPen(QColor(0x00, 0x00, 0x80))
+            if self.is_constant:
+                painter.setPen(self._config.disasm_view_operand_constant_color)
+            else:
+                painter.setPen(self._config.disasm_view_operand_color)
 
         painter.setRenderHints(
                 QPainter.Antialiasing | QPainter.SmoothPixmapTransform | QPainter.HighQualityAntialiasing)
@@ -189,9 +192,9 @@ class QOperand(QCachedGraphicsItem):
         # {s_10}
         if self.disasm_view.show_variable and self._variable_label:
             x += self.LABEL_VARIABLE_SPACING * self.currentDevicePixelRatioF()
-            painter.setPen(QColor(0x00, 0x80, 0x00))
+            painter.setPen(self._config.disasm_view_variable_label_color)
             painter.drawText(x, y, self._variable_label)
-            painter.setPen(QColor(0x00, 0x00, 0x80))
+            painter.setPen(self._config.disasm_view_operand_color)
             x += self._variable_label_width
 
         # draw additional branch targets
@@ -208,7 +211,7 @@ class QOperand(QCachedGraphicsItem):
             x += self._variable_ident_width
 
         # restores the color
-        painter.setPen(QColor(0, 0, 0x80))
+        painter.setPen(self._config.disasm_view_operand_color)
 
     #
     # Private methods
@@ -236,7 +239,7 @@ class QOperand(QCachedGraphicsItem):
         # try to render it
         rendered = operand.render()[0]
         for t in branch_targets:
-            if "%x" % t == rendered or "%#x" % t == rendered:
+            if rendered in ("%x" % t, "%#x" % t):
                 return t
             if t == rendered:
                 return t
@@ -246,7 +249,8 @@ class QOperand(QCachedGraphicsItem):
         # return a random one
         return next(iter(branch_targets))
 
-    def _first_n_branch_targets(self, branch_targets, n):
+    @staticmethod
+    def _first_n_branch_targets(branch_targets, n):
 
         if not branch_targets:
             return [ ]
@@ -258,12 +262,8 @@ class QOperand(QCachedGraphicsItem):
         if self.is_branch_target:
             # a branch instruction
 
-            if self.branch_targets is not None and next(iter(self.branch_targets)) in self.disasm.kb.functions:
-                # jumping to a function
-                is_target_func = True
-            else:
-                # jumping to a non-function address
-                is_target_func = False
+            is_target_func = bool(self.branch_targets is not None
+                                  and next(iter(self.branch_targets)) in self.disasm.kb.functions)
 
             if self.is_indirect_branch:
                 # indirect jump
