@@ -2,12 +2,13 @@ from PySide2.QtWidgets import QDockWidget
 
 
 class QSmartDockWidget(QDockWidget):
-    def __init__(self, caption, parent=None):
+    def __init__(self, caption, parent=None, on_close=None):
         super(QSmartDockWidget, self).__init__(caption, parent)
 
         self.old_size = None
         self.original_min = None
         self.original_max = None
+        self._on_close = on_close
 
     def restore_original_size(self):
 
@@ -18,3 +19,8 @@ class QSmartDockWidget(QDockWidget):
         self.setMinimumHeight(self.original_min.height())
         self.setMaximumWidth(self.original_max.width())
         self.setMaximumHeight(self.original_max.height())
+
+    def closeEvent(self, event):
+        if self._on_close is not None:
+            self._on_close()
+        return super().closeEvent(event)
