@@ -88,7 +88,8 @@ class Workspace:
         self._get_or_create_disassembly_view().display_function(func)
         codeview = self.view_manager.first_view_in_category('pseudocode')
         if codeview is not None and codeview.is_shown():
-            self.decompile_function(func, view=codeview)
+            codeview.function.am_obj = func
+            codeview.function.am_event(focus=True)
 
     def on_cfg_generated(self):
 
@@ -110,6 +111,12 @@ class Workspace:
             # Initialize the linear viewer
             self.view_manager.first_view_in_category('disassembly')._linear_viewer.initialize()
 
+            # Reload the pseudocode view
+            self.view_manager.first_view_in_category('pseudocode').reload()
+
+            # Reload the strings view
+            self.view_manager.first_view_in_category('strings').reload()
+
     def _on_prototype_found(self):
         self.instance.add_job(
             VariableRecoveryJob(
@@ -125,6 +132,7 @@ class Workspace:
         )
 
     def on_function_tagged(self):
+        # reload disassembly view
         view = self.view_manager.first_view_in_category('disassembly')
         if view is not None:
             view: DisassemblyView
@@ -240,11 +248,11 @@ class Workspace:
         elif type(obj) is Function:
             self.jump_to(obj.addr)
 
-    def jump_to(self, addr, view=None):
+    def jump_to(self, addr, view=None, use_animation=False):
         if view is None or view.category != "disassembly":
             view = self._get_or_create_disassembly_view()
 
-        view.jump_to(addr)
+        view.jump_to(addr, use_animation=use_animation)
         self.raise_view(view)
         view.setFocus()
 
@@ -264,11 +272,13 @@ class Workspace:
             # redraw
             disasm_view.current_graph.refresh()
 
-    def decompile_current_function(self, view=None):
-        if view is None or view.category != "disassembly":
+    def decompile_current_function(self):
+        current = self.view_manager.current_tab
+        if isinstance(current, CodeView):
+            current.decompile()
+        else:
             view = self._get_or_create_disassembly_view()
-
-        view.decompile_current_function()
+            view.decompile_current_function()
 
     def view_proximity_for_current_function(self, view=None):
         if view is None or view.category != "proximity":
@@ -280,22 +290,6 @@ class Workspace:
 
         self.raise_view(view)
 
-    def position_cursor_on_decomp(self, view, curr_ins):
-        if view is not None and curr_ins is not None:
-            # get the Qt document
-            doc = view.document
-
-            # get closest node for ins
-            new_text_pos = doc.find_closest_node_pos(curr_ins)
-
-            if new_text_pos is not None:
-                # set the new cursor position
-                textedit = view.textedit
-                cursor = textedit.textCursor()
-                cursor.setPosition(new_text_pos)
-                textedit.setTextCursor(cursor)
-                textedit.setFocus()
-
     def decompile_function(self, func: Function, curr_ins=None, view=None):
         """
         Decompile a function a switch to decompiled view. If curr_ins is
@@ -311,12 +305,8 @@ class Workspace:
         if view is None or view.category != "pseudocode":
             view = self._get_or_create_pseudocode_view()
 
-        view.function = func
-        self.raise_view(view)
-        view.setFocus()
-
-        # correspond disass location to new decomp position
-        self.position_cursor_on_decomp(view, curr_ins)
+        view.function.am_obj = func
+        view.function.am_event(focus=True, focus_addr=curr_ins)
 
     def create_simulation_manager(self, state, state_name, view=None):
 
@@ -352,6 +342,18 @@ class Workspace:
             console.print_text(msg)
             console.print_text('\n')
 
+    def show_linear_disassembly_view(self):
+        view = self._get_or_create_disassembly_view()
+        view.display_linear_viewer()
+        self.raise_view(view)
+        view.setFocus()
+
+    def show_graph_disassembly_view(self):
+        view = self._get_or_create_disassembly_view()
+        view.display_disasm_graph()
+        self.raise_view(view)
+        view.setFocus()
+
     #
     # Private methods
     #
@@ -362,7 +364,7 @@ class Workspace:
 
         if view is None:
             # Create a new disassembly view
-            view = DisassemblyView(self, 'right')
+            view = DisassemblyView(self, 'center')
             self.add_view(view, view.caption, view.category)
 
         return view
@@ -373,7 +375,7 @@ class Workspace:
 
         if view is None:
             # Create a new pseudo-code view
-            view = CodeView(self, 'right')
+            view = CodeView(self, 'center')
             self.add_view(view, view.caption, view.category)
 
         return view
@@ -384,7 +386,7 @@ class Workspace:
 
         if view is None:
             # Create a new symexec view
-            view = CodeView(self, 'right')
+            view = CodeView(self, 'center')
             self.add_view(view, view.caption, view.category)
 
         return view
@@ -393,7 +395,7 @@ class Workspace:
         view = self.view_manager.first_view_in_category("interaction")
         if view is None:
             # Create a new interaction view
-            view = InteractionView(self, 'right')
+            view = InteractionView(self, 'center')
             self.add_view(view, view.caption, view.category)
         return view
 
